// (c) Copyright 2011-2012 Cloudera, Inc. All rights reserved.
define([
  'cloudera/cmf/wizard/express/ParcelInstallStep'
], function(ParcelInstallStep) {
  describe("ParcelInstallStep Tests", function() {
    var id = "parcelInstallStep", module;
    var callback = function() {};
    var options = {
      id: id,
      updateUrl: "dontcare",
      installUrl: "dontcare",
      cluster: function() {
        return {
          id: 1,
          name: "My Cluster"
        };
      },
      parcels: function() {
        return [];
      },
      displayPageWhenActivated: false
    };
    var clusterInfo = {
      "name":"Cluster 1 - CDH4",
      "urls":{
        "activateUrl": "/cmf/clusters/4/activateParcel",
        "distributeUrl": "/cmf/clusters/4/distributeParcels",
        "deactivateUrl": "/cmf/clusters/4/deactivateParcel",
        "downloadUrl": "/cmf/parcel/downloadUpstream",
        "undistributeUrl": "/cmf/clusters/4/undistributeParcels",
        "cancelUrl": "/cmf/clusters/4/cancelParcel"
      }
    };

    beforeEach(function() {
      $("<div>").attr("id", id).appendTo(document.body);
      jasmine.Ajax.useMock();
      clearAjaxRequests();
    });

    afterEach(function() {
      $("#" + id).remove();
    });

    it("should initialize a ParcelInstallStep and test showParcelContent()", function() {
      module = new ParcelInstallStep(options);
      module.beforeEnter(callback);

      var request = mostRecentAjaxRequest();
      request.response({
        status: 200,
        responseText: JSON.stringify([{
          "cluster":clusterInfo,
          "states":[{
            "version":"5.0","product":"CDH","releaseNotes":null,"isUpgradeNeeded":false,
            "state":{
              "stage":"ACTIVATED","count":0,"progress":0,"totalProgress":4800,"totalCount":48,
              "combinedProgress":0,"combinedTotalProgress":100
            }
          }]
        }])
      });
      expect(module.showParcelContent()).toBeFalsy();
    });

    it("should initialize a ParcelInstallStep and test showParcelContent() when something is downloading", function() {
      module = new ParcelInstallStep(options);
      module.beforeEnter(callback);

      var request = mostRecentAjaxRequest();
      request.response({
        status: 200,
        responseText: JSON.stringify([{
          "cluster":clusterInfo,
          "states":[{
            "version":"5.0","product":"CDH","releaseNotes":null,"isUpgradeNeeded":false,
            "state":{
              "stage":"DOWNLOADING","count":0,"progress":0,"totalProgress":4800,"totalCount":48,
              "combinedProgress":0,"combinedTotalProgress":100
            }
          }]
        }])
      });
      expect(module.showParcelContent()).toBeTruthy();
    });

    it("should initialize a ParcelInstallStep and test showParcelContent() when ACTIVATED but displayPageWhenActivated = true", function() {
      module = new ParcelInstallStep(options);
      module.beforeEnter(callback);

      var request = mostRecentAjaxRequest();
      request.response({
        status: 200,
        responseText: JSON.stringify([{
          "cluster":clusterInfo,
          "states":[{
            "version":"5.0","product":"CDH","releaseNotes":null,"isUpgradeNeeded":false,
            "state":{
              "stage":"DOWNLOADING","count":0,"progress":0,"totalProgress":4800,"totalCount":48,
              "combinedProgress":0,"combinedTotalProgress":100
            }
          }]
        }])
      });
      expect(module.showParcelContent()).toBeTruthy();
    });
  });
});
